@@ -32,7 +32,7 @@ use utf8;
 use Log::Any qw($log);
 use Carp;
 
-use constant VERSION => '24.11';
+use constant VERSION => '24.12';
 
 =head1 Name
 
@@ -52,7 +52,7 @@ default: 180
 
 String. custom UserAgent header
 
-default: Swagger-Codegen/22.5/perl
+default: Swagger-CodeGen/22.5/perl
 
 =item api_key: (optional)
 
@@ -111,7 +111,7 @@ sub new {
 
 	# class/static variables
 	$p{http_timeout} //= 180;
-	$p{http_user_agent} //= 'Apose.Cells.Cloud.SDK/24.11/perl';
+	$p{http_user_agent} //= 'Apose.Cells.Cloud.SDK/24.12/perl';
 
 	# authentication setting
 	$p{api_key} //= {};
