@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -129,63 +129,70 @@ __PACKAGE__->method_documentation({
      'source_folder' => {
      	datatype => 'string',
      	base_name => 'SourceFolder',
-     	description => '',
+     	description => 'The directory stores files that need to format conversion.            ',
      	format => '',
      	read_only => '',
      		},
      'source_storage' => {
      	datatype => 'string',
      	base_name => 'SourceStorage',
-     	description => '',
+     	description => 'Aspose Cloud storage name',
      	format => '',
      	read_only => '',
      		},
      'match_condition' => {
      	datatype => 'MatchConditionRequest',
      	base_name => 'MatchCondition',
-     	description => '',
+     	description => 'Indicates the match condition that needs to be processed for the file name.',
      	format => '',
      	read_only => '',
      		},
      'format' => {
      	datatype => 'string',
      	base_name => 'Format',
-     	description => '',
+     	description => 'Output file format',
      	format => '',
      	read_only => '',
      		},
      'from_index' => {
      	datatype => 'int',
      	base_name => 'FromIndex',
-     	description => '',
+     	description => 'From worksheet index of workbook.',
      	format => '',
      	read_only => '',
      		},
      'to_index' => {
      	datatype => 'int',
      	base_name => 'ToIndex',
-     	description => '',
+     	description => 'To worksheet index of workbook.',
      	format => '',
      	read_only => '',
      		},
      'out_folder' => {
      	datatype => 'string',
      	base_name => 'OutFolder',
-     	description => '',
+     	description => 'The directory that stores files whose format conversion was successful.',
      	format => '',
      	read_only => '',
      		},
      'out_storage' => {
      	datatype => 'string',
      	base_name => 'OutStorage',
-     	description => '',
+     	description => 'Aspose Cloud storage name.',
+     	format => '',
+     	read_only => '',
+     		},
+     'region' => {
+     	datatype => 'string',
+     	base_name => 'Region',
+     	description => 'The regional settings for workbook.',
      	format => '',
      	read_only => '',
      		},
      'save_options' => {
      	datatype => 'SaveOptions',
      	base_name => 'SaveOptions',
-     	description => '',
+     	description => 'Indicates save options.',
      	format => '',
      	read_only => '',
      		},    
@@ -200,6 +207,7 @@ __PACKAGE__->swagger_types( {
     'to_index' => 'int',
     'out_folder' => 'string',
     'out_storage' => 'string',
+    'region' => 'string',
     'save_options' => 'SaveOptions' 
 } );
 
@@ -212,6 +220,7 @@ __PACKAGE__->attribute_map( {
     'to_index' => 'ToIndex',
     'out_folder' => 'OutFolder',
     'out_storage' => 'OutStorage',
+    'region' => 'Region',
     'save_options' => 'SaveOptions' 
 } );
 
