@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents a chart data table.',
                                   class => 'ChartDataTable',
                                   required => [], # TODO
 }                                 );
@@ -131,56 +131,56 @@ __PACKAGE__->method_documentation({
      'auto_scale_font' => {
      	datatype => 'boolean',
      	base_name => 'AutoScaleFont',
-     	description => '',
+     	description => 'True if the text in the object changes font size when the object size changes.                         The default value is True.',
      	format => '',
      	read_only => '',
      		},
      'background_mode' => {
      	datatype => 'string',
      	base_name => 'BackgroundMode',
-     	description => '',
+     	description => 'Gets and sets the display mode of the background',
      	format => '',
      	read_only => '',
      		},
      'border' => {
      	datatype => 'Line',
      	base_name => 'Border',
-     	description => '',
+     	description => 'Returns a Border object that represents the border of the object',
      	format => '',
      	read_only => '',
      		},
      'font' => {
      	datatype => 'Font',
      	base_name => 'Font',
-     	description => '',
+     	description => 'Gets a  object which represents the font setting of the specified chart data table.',
      	format => '',
      	read_only => '',
      		},
      'has_border_horizontal' => {
      	datatype => 'boolean',
      	base_name => 'HasBorderHorizontal',
-     	description => '',
+     	description => 'True if the chart data table has horizontal cell borders',
      	format => '',
      	read_only => '',
      		},
      'has_border_outline' => {
      	datatype => 'boolean',
      	base_name => 'HasBorderOutline',
-     	description => '',
+     	description => 'True if the chart data table has outline borders',
      	format => '',
      	read_only => '',
      		},
      'has_border_vertical' => {
      	datatype => 'boolean',
      	base_name => 'HasBorderVertical',
-     	description => '',
+     	description => 'True if the chart data table has vertical cell borders',
      	format => '',
      	read_only => '',
      		},
      'show_legend_key' => {
      	datatype => 'boolean',
      	base_name => 'ShowLegendKey',
-     	description => '',
+     	description => 'True if the data label legend key is visible.',
      	format => '',
      	read_only => '',
      		},
