@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the shape of the comment.',
                                   class => 'CommentShape',
                                   required => [], # TODO
 }                                 );
@@ -131,7 +131,7 @@ __PACKAGE__->method_documentation({
      'comment' => {
      	datatype => 'LinkElement',
      	base_name => 'Comment',
-     	description => '',
+     	description => 'Gets the comment object.',
      	format => '',
      	read_only => '',
      		},
