@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Represents the custom filter.           ',
                                   class => 'CustomFilter',
                                   required => [], # TODO
 }                                 );
@@ -128,14 +128,14 @@ __PACKAGE__->method_documentation({
      'criteria' => {
      	datatype => 'string',
      	base_name => 'Criteria',
-     	description => '',
+     	description => 'Gets and sets the criteria. ',
      	format => '',
      	read_only => '',
      		},
      'filter_operator_type' => {
      	datatype => 'string',
      	base_name => 'FilterOperatorType',
-     	description => '',
+     	description => 'Gets and sets the filter operator type. ',
      	format => '',
      	read_only => '',
      		},    
