@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Represents a range of characters within the cell text.           ',
                                   class => 'FontSetting',
                                   required => [], # TODO
 }                                 );
@@ -129,35 +129,35 @@ __PACKAGE__->method_documentation({
      'font' => {
      	datatype => 'Font',
      	base_name => 'Font',
-     	description => '',
+     	description => 'Returns the font of this object. ',
      	format => '',
      	read_only => '',
      		},
      'length' => {
      	datatype => 'int',
      	base_name => 'Length',
-     	description => '',
+     	description => 'Gets the length of the characters. ',
      	format => '',
      	read_only => '',
      		},
      'start_index' => {
      	datatype => 'int',
      	base_name => 'StartIndex',
-     	description => '',
+     	description => 'Gets the start index of the characters. ',
      	format => '',
      	read_only => '',
      		},
      'text_options' => {
      	datatype => 'TextOptions',
      	base_name => 'TextOptions',
-     	description => '',
+     	description => 'Returns the text options. ',
      	format => '',
      	read_only => '',
      		},
      'type' => {
      	datatype => 'string',
      	base_name => 'Type',
-     	description => '',
+     	description => 'Gets the type of text node. ',
      	format => '',
      	read_only => '',
      		},    
