@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -120,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Encapsulates the object that represents a label in a spreadsheet.',
                                   class => 'Label',
                                   required => [], # TODO
 }                                 );
@@ -256,7 +256,7 @@ __PACKAGE__->method_documentation({
      'text' => {
      	datatype => 'string',
      	base_name => 'Text',
-     	description => '',
+     	description => 'Gets or sets the text of display unit label.',
      	format => '',
      	read_only => '',
      		},
