@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -122,7 +122,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Encapsulates the object that represents the chart legend.',
                                   class => 'Legend',
                                   required => [], # TODO
 }                                 );
@@ -132,14 +132,14 @@ __PACKAGE__->method_documentation({
      'position' => {
      	datatype => 'string',
      	base_name => 'Position',
-     	description => '',
+     	description => 'Gets or sets the legend position type.',
      	format => '',
      	read_only => '',
      		},
      'legend_entries' => {
      	datatype => 'LinkElement',
      	base_name => 'LegendEntries',
-     	description => '',
+     	description => 'Gets a collection of all the LegendEntry objects in the specified chart legend.                        Setting the legend entries of the surface chart is not supported.                        So it will return null if the chart type is surface chart type.',
      	format => '',
      	read_only => '',
      		},
@@ -199,13 +199,6 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
-     'shape_properties' => {
-     	datatype => 'ARRAY[LinkElement]',
-     	base_name => 'ShapeProperties',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
      'width' => {
      	datatype => 'int',
      	base_name => 'Width',
@@ -247,7 +240,6 @@ __PACKAGE__->swagger_types( {
     'is_automatic_size' => 'boolean',
     'is_inner_mode' => 'boolean',
     'shadow' => 'boolean',
-    'shape_properties' => 'ARRAY[LinkElement]',
     'width' => 'int',
     'height' => 'int',
     'x' => 'int',
@@ -265,7 +257,6 @@ __PACKAGE__->attribute_map( {
     'is_automatic_size' => 'IsAutomaticSize',
     'is_inner_mode' => 'IsInnerMode',
     'shadow' => 'Shadow',
-    'shape_properties' => 'ShapeProperties',
     'width' => 'Width',
     'height' => 'Height',
     'x' => 'X',
