@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -120,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the line shape.',
                                   class => 'LineShape',
                                   required => [], # TODO
 }                                 );
@@ -130,42 +130,42 @@ __PACKAGE__->method_documentation({
      'begin_arrowhead_length' => {
      	datatype => 'string',
      	base_name => 'BeginArrowheadLength',
-     	description => '',
+     	description => 'Gets and sets the begin arrow head length of the line.',
      	format => '',
      	read_only => '',
      		},
      'begin_arrowhead_style' => {
      	datatype => 'string',
      	base_name => 'BeginArrowheadStyle',
-     	description => '',
+     	description => 'Gets and sets the begin arrow head style of the line.',
      	format => '',
      	read_only => '',
      		},
      'begin_arrowhead_width' => {
      	datatype => 'string',
      	base_name => 'BeginArrowheadWidth',
-     	description => '',
+     	description => 'Gets and sets the begin arrow head width of the line.',
      	format => '',
      	read_only => '',
      		},
      'end_arrowhead_length' => {
      	datatype => 'string',
      	base_name => 'EndArrowheadLength',
-     	description => '',
+     	description => 'Gets and sets the end arrow head length of the line.',
      	format => '',
      	read_only => '',
      		},
      'end_arrowhead_style' => {
      	datatype => 'string',
      	base_name => 'EndArrowheadStyle',
-     	description => '',
+     	description => 'Gets and sets the end arrow head style of the line.',
      	format => '',
      	read_only => '',
      		},
      'end_arrowhead_width' => {
      	datatype => 'string',
      	base_name => 'EndArrowheadWidth',
-     	description => '',
+     	description => 'Gets and sets the end arrow head width of the line.',
      	format => '',
      	read_only => '',
      		},
