@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents a list box object.',
                                   class => 'ListBox',
                                   required => [], # TODO
 }                                 );
@@ -138,42 +138,42 @@ __PACKAGE__->method_documentation({
      'item_count' => {
      	datatype => 'int',
      	base_name => 'ItemCount',
-     	description => '',
+     	description => 'Gets the number of items in the list box.',
      	format => '',
      	read_only => '',
      		},
      'page_change' => {
      	datatype => 'int',
      	base_name => 'PageChange',
-     	description => '',
+     	description => 'Specifies the amount by which the control`s value is changed                         when the user clicks on the scrollbar`s page up or page down region.',
      	format => '',
      	read_only => '',
      		},
      'selected_cells' => {
      	datatype => 'ARRAY[LinkElement]',
      	base_name => 'SelectedCells',
-     	description => '',
+     	description => 'Gets the selected cells.                        Returns null if the input range is not set or no item is selected',
      	format => '',
      	read_only => '',
      		},
      'selected_index' => {
      	datatype => 'int',
      	base_name => 'SelectedIndex',
-     	description => '',
+     	description => 'Gets or sets the index number of the currently selected item in a list box or combo box.                        Zero-based.',
      	format => '',
      	read_only => '',
      		},
      'selection_type' => {
      	datatype => 'string',
      	base_name => 'SelectionType',
-     	description => '',
+     	description => 'Gets or sets the selection mode of the specified list box.',
      	format => '',
      	read_only => '',
      		},
      'shadow' => {
      	datatype => 'boolean',
      	base_name => 'Shadow',
-     	description => '',
+     	description => 'Indicates whether the combobox has 3-D shading.',
      	format => '',
      	read_only => '',
      		},
