@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents options of saving .mhtml file.',
                                   class => 'MHtmlSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -128,84 +128,84 @@ __PACKAGE__->method_documentation({
      'attached_files_directory' => {
      	datatype => 'string',
      	base_name => 'AttachedFilesDirectory',
-     	description => '',
+     	description => 'The directory that the attached files will be saved to.  Only for saving to html stream.',
      	format => '',
      	read_only => '',
      		},
      'attached_files_url_prefix' => {
      	datatype => 'string',
      	base_name => 'AttachedFilesUrlPrefix',
-     	description => '',
+     	description => 'Specify the Url prefix of attached files such as image in the html file. Only for saving to html stream.',
      	format => '',
      	read_only => '',
      		},
      'encoding' => {
      	datatype => 'string',
      	base_name => 'Encoding',
-     	description => '',
+     	description => 'If not set,use Encoding.UTF8 as default enconding type.',
      	format => '',
      	read_only => '',
      		},
      'export_active_worksheet_only' => {
      	datatype => 'boolean',
      	base_name => 'ExportActiveWorksheetOnly',
-     	description => '',
+     	description => 'Indicates if exporting the whole workbook to html file.',
      	format => '',
      	read_only => '',
      		},
      'export_chart_image_format' => {
      	datatype => 'string',
      	base_name => 'ExportChartImageFormat',
-     	description => '',
+     	description => 'Get or set the format of chart image before exporting',
      	format => '',
      	read_only => '',
      		},
      'export_images_as_base64' => {
      	datatype => 'boolean',
      	base_name => 'ExportImagesAsBase64',
-     	description => '',
+     	description => 'Specifies whether images are saved in Base64 format to HTML, MHTML or EPUB.',
      	format => '',
      	read_only => '',
      		},
      'hidden_col_display_type' => {
      	datatype => 'string',
      	base_name => 'HiddenColDisplayType',
-     	description => '',
+     	description => 'Hidden column(the width of this column is 0) in excel,before save this into                html format, if HtmlHiddenColDisplayType is "Remove",the hidden column would               ont been output, if the value is "Hidden", the column would been output,but was hidden,the default value is "Hidden"',
      	format => '',
      	read_only => '',
      		},
      'hidden_row_display_type' => {
      	datatype => 'string',
      	base_name => 'HiddenRowDisplayType',
-     	description => '',
+     	description => 'Hidden row(the height of this row is 0) in excel,before save this into html                format, if HtmlHiddenRowDisplayType is "Remove",the hidden row would ont               been output, if the value is "Hidden", the row would been output,but was               hidden,the default value is "Hidden"',
      	format => '',
      	read_only => '',
      		},
      'html_cross_string_type' => {
      	datatype => 'string',
      	base_name => 'HtmlCrossStringType',
-     	description => '',
+     	description => 'Indicates if a cross-cell string will be displayed in the same way as MS               Excel when saving an Excel file in html format.  By default the value is               Default, so, for cross-cell strings, there is little difference between the               html files created by Aspose.Cells and MS Excel. But the performance for               creating large html files,setting the value to Cross would be several times               faster than setting it to Default or Fit2Cell.',
      	format => '',
      	read_only => '',
      		},
      'is_exp_image_to_temp_dir' => {
      	datatype => 'boolean',
      	base_name => 'IsExpImageToTempDir',
-     	description => '',
+     	description => 'Indicates if export image files to temp directory.  Only for saving to html  stream.',
      	format => '',
      	read_only => '',
      		},
      'page_title' => {
      	datatype => 'string',
      	base_name => 'PageTitle',
-     	description => '',
+     	description => 'The title of the html page.  Only for saving to html stream.',
      	format => '',
      	read_only => '',
      		},
      'parse_html_tag_in_cell' => {
      	datatype => 'boolean',
      	base_name => 'ParseHtmlTagInCell',
-     	description => '',
+     	description => 'Parse html tag in cell,like ,as cell value,or as html tag,default is true',
      	format => '',
      	read_only => '',
      		},
