@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents sort key.',
                                   class => 'SortKey',
                                   required => [], # TODO
 }                                 );
@@ -128,14 +128,14 @@ __PACKAGE__->method_documentation({
      'key' => {
      	datatype => 'int',
      	base_name => 'Key',
-     	description => '',
+     	description => 'Represents the key of sorting.',
      	format => '',
      	read_only => '',
      		},
      'sort_order' => {
      	datatype => 'string',
      	base_name => 'SortOrder',
-     	description => '',
+     	description => 'Represents the order of sorting.',
      	format => '',
      	read_only => '',
      		},
@@ -149,21 +149,21 @@ __PACKAGE__->method_documentation({
      'order' => {
      	datatype => 'string',
      	base_name => 'Order',
-     	description => '',
+     	description => 'Indicates the order of sorting.',
      	format => '',
      	read_only => '',
      		},
      'index' => {
      	datatype => 'int',
      	base_name => 'Index',
-     	description => '',
+     	description => 'Gets the sorted column index(absolute position, column A is 0, B is 1, ...).',
      	format => '',
      	read_only => '',
      		},
      'type' => {
      	datatype => 'string',
      	base_name => 'Type',
-     	description => '',
+     	description => 'Represents the type of sorting.',
      	format => '',
      	read_only => '',
      		},    
