@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Represents display style of excel document,such as font,color,alignment,border,etc.            The Style object contains all style attributes (font, number format, alignment, and so on) as properties.           ',
                                   class => 'Style',
                                   required => [], # TODO
 }                                 );
@@ -131,140 +131,140 @@ __PACKAGE__->method_documentation({
      'font' => {
      	datatype => 'Font',
      	base_name => 'Font',
-     	description => '',
+     	description => 'Gets a  object. ',
      	format => '',
      	read_only => '',
      		},
      'name' => {
      	datatype => 'string',
      	base_name => 'Name',
-     	description => '',
+     	description => 'Gets or sets the name of the style. ',
      	format => '',
      	read_only => '',
      		},
      'culture_custom' => {
      	datatype => 'string',
      	base_name => 'CultureCustom',
-     	description => '',
+     	description => 'Gets and sets the culture-dependent pattern string for number format.            If no number format has been set for this object, null will be returned.            If number format is builtin, the pattern string corresponding to the builtin number will be returned. ',
      	format => '',
      	read_only => '',
      		},
      'custom' => {
      	datatype => 'string',
      	base_name => 'Custom',
-     	description => '',
+     	description => 'Represents the custom number format string of this style object.            If the custom number format is not set(For example, the number format is builtin), "" will be returned. ',
      	format => '',
      	read_only => '',
      		},
      'background_color' => {
      	datatype => 'Color',
      	base_name => 'BackgroundColor',
-     	description => '',
+     	description => 'Gets or sets a style`s background color. ',
      	format => '',
      	read_only => '',
      		},
      'foreground_color' => {
      	datatype => 'Color',
      	base_name => 'ForegroundColor',
-     	description => '',
+     	description => 'Gets or sets a style`s foreground color. ',
      	format => '',
      	read_only => '',
      		},
      'is_formula_hidden' => {
      	datatype => 'boolean',
      	base_name => 'IsFormulaHidden',
-     	description => '',
+     	description => 'Represents if the formula will be hidden when the worksheet is protected. ',
      	format => '',
      	read_only => '',
      		},
      'is_date_time' => {
      	datatype => 'boolean',
      	base_name => 'IsDateTime',
-     	description => '',
+     	description => 'Indicates whether the number format is a date format. ',
      	format => '',
      	read_only => '',
      		},
      'is_text_wrapped' => {
      	datatype => 'boolean',
      	base_name => 'IsTextWrapped',
-     	description => '',
+     	description => 'Gets or sets a value indicating whether the text within a cell is wrapped. ',
      	format => '',
      	read_only => '',
      		},
      'is_gradient' => {
      	datatype => 'boolean',
      	base_name => 'IsGradient',
-     	description => '',
+     	description => 'Indicates whether the cell shading is a gradient pattern. ',
      	format => '',
      	read_only => '',
      		},
      'is_locked' => {
      	datatype => 'boolean',
      	base_name => 'IsLocked',
-     	description => '',
+     	description => 'Gets or sets a value indicating whether a cell can be modified or not. ',
      	format => '',
      	read_only => '',
      		},
      'is_percent' => {
      	datatype => 'boolean',
      	base_name => 'IsPercent',
-     	description => '',
+     	description => 'Indicates whether the number format is a percent format. ',
      	format => '',
      	read_only => '',
      		},
      'shrink_to_fit' => {
      	datatype => 'boolean',
      	base_name => 'ShrinkToFit',
-     	description => '',
+     	description => 'Represents if text automatically shrinks to fit in the available column width. ',
      	format => '',
      	read_only => '',
      		},
      'indent_level' => {
      	datatype => 'int',
      	base_name => 'IndentLevel',
-     	description => '',
+     	description => 'Represents the indent level for the cell or range. Can only be an integer from 0 to 250. ',
      	format => '',
      	read_only => '',
      		},
      'number' => {
      	datatype => 'int',
      	base_name => 'Number',
-     	description => '',
+     	description => 'Gets or sets the display format of numbers and dates. The formatting patterns are different for different regions. ',
      	format => '',
      	read_only => '',
      		},
      'rotation_angle' => {
      	datatype => 'int',
      	base_name => 'RotationAngle',
-     	description => '',
+     	description => 'Represents text rotation angle. ',
      	format => '',
      	read_only => '',
      		},
      'pattern' => {
      	datatype => 'string',
      	base_name => 'Pattern',
-     	description => '',
+     	description => 'Gets or sets the cell background pattern type. ',
      	format => '',
      	read_only => '',
      		},
      'text_direction' => {
      	datatype => 'string',
      	base_name => 'TextDirection',
-     	description => '',
+     	description => 'Represents text reading order. ',
      	format => '',
      	read_only => '',
      		},
      'vertical_alignment' => {
      	datatype => 'string',
      	base_name => 'VerticalAlignment',
-     	description => '',
+     	description => 'Gets or sets the vertical alignment type of the text in a cell. ',
      	format => '',
      	read_only => '',
      		},
      'horizontal_alignment' => {
      	datatype => 'string',
      	base_name => 'HorizontalAlignment',
-     	description => '',
+     	description => 'Gets or sets the horizontal alignment type of the text in a cell. ',
      	format => '',
      	read_only => '',
      		},
@@ -278,14 +278,14 @@ __PACKAGE__->method_documentation({
      'background_theme_color' => {
      	datatype => 'ThemeColor',
      	base_name => 'BackgroundThemeColor',
-     	description => '',
+     	description => 'Gets and sets the background theme color. ',
      	format => '',
      	read_only => '',
      		},
      'foreground_theme_color' => {
      	datatype => 'ThemeColor',
      	base_name => 'ForegroundThemeColor',
-     	description => '',
+     	description => 'Gets and sets the foreground theme color. ',
      	format => '',
      	read_only => '',
      		},    
