@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents time period format condition.',
                                   class => 'TimePeriodFormatCondition',
                                   required => [], # TODO
 }                                 );
@@ -128,7 +128,7 @@ __PACKAGE__->method_documentation({
      'time_period' => {
      	datatype => 'string',
      	base_name => 'TimePeriod',
-     	description => '',
+     	description => 'The applicable time period in a "date occurring…" conditional formatting                rule. Valid only for type = timePeriod.  The default value is TimePeriodType.Today',
      	format => '',
      	read_only => '',
      		},    
