@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -128,21 +128,21 @@ __PACKAGE__->method_documentation({
      'is_bottom' => {
      	datatype => 'boolean',
      	base_name => 'IsBottom',
-     	description => 'Get or set the flag indicating whether a "top/bottom n" rule is a "bottom   n" rule. `1` indicates `bottom`.  Default value is false.            ',
+     	description => 'Get or set whether a "top/bottom n" rule is a "bottom n" rule.            Default value is false. ',
      	format => '',
      	read_only => '',
      		},
      'is_percent' => {
      	datatype => 'boolean',
      	base_name => 'IsPercent',
-     	description => 'Get or set the flag indicating whether a "top/bottom n" rule is a "top/bottom    n percent" rule.  Default value is false.',
+     	description => 'Get or set whether a "top/bottom n" rule is a "top/bottom n percent" rule.            Default value is false. ',
      	format => '',
      	read_only => '',
      		},
      'rank' => {
      	datatype => 'int',
      	base_name => 'Rank',
-     	description => 'Get or set the value of "n" in a "top/bottom n" conditional formatting rule.     If IsPercent is true, the value must between 0 and 100.  Otherwise it must    between 0 and 1000.  Default value is 10.',
+     	description => 'Get or set the value of "n" in a "top/bottom n" conditional formatting rule.            If IsPercent is true, the value must between 0 and 100.            Otherwise it must between 0 and 1000.            Default value is 10. ',
      	format => '',
      	read_only => '',
      		},    
