@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# DeleteWorksheetOleObjectRequest.name :   ,
-# DeleteWorksheetOleObjectRequest.sheetName :   ,
-# DeleteWorksheetOleObjectRequest.oleObjectIndex :   ,
-# DeleteWorksheetOleObjectRequest.folder :   ,
-# DeleteWorksheetOleObjectRequest.storageName :    
+# DeleteWorksheetOleObjectRequest.name : The file name.  ,
+# DeleteWorksheetOleObjectRequest.sheetName : The worsheet name.  ,
+# DeleteWorksheetOleObjectRequest.oleObjectIndex : Ole object index.  ,
+# DeleteWorksheetOleObjectRequest.folder : The folder where the file is situated.  ,
+# DeleteWorksheetOleObjectRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_worksheet_ole_object' } = { 
-    	summary => '',
+    	summary => 'Delete an OLE object in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -137,35 +137,35 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worsheet name.',
      	format => '',
      	read_only => '',
      		},
      'ole_object_index' => {
      	datatype => 'int',
      	base_name => 'oleObjectIndex',
-     	description => '',
+     	description => 'Ole object index.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
