@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,13 +59,13 @@ sub new {
 
 
 # Run Operation Request
-# PostAutofitWorksheetRowRequest.name :   ,
-# PostAutofitWorksheetRowRequest.sheetName :   ,
-# PostAutofitWorksheetRowRequest.rowIndex :   ,
-# PostAutofitWorksheetRowRequest.firstColumn :   ,
-# PostAutofitWorksheetRowRequest.lastColumn :   ,
-# PostAutofitWorksheetRowRequest.folder :   ,
-# PostAutofitWorksheetRowRequest.storageName :    
+# PostAutofitWorksheetRowRequest.name : The file name.  ,
+# PostAutofitWorksheetRowRequest.sheetName : The worksheet name.  ,
+# PostAutofitWorksheetRowRequest.rowIndex : The row index.  ,
+# PostAutofitWorksheetRowRequest.firstColumn : The first column index.  ,
+# PostAutofitWorksheetRowRequest.lastColumn : The last column index.  ,
+# PostAutofitWorksheetRowRequest.folder : The folder where the file is situated.  ,
+# PostAutofitWorksheetRowRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -76,7 +76,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_autofit_worksheet_row' } = { 
-    	summary => '',
+    	summary => 'Autofit a row in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -145,49 +145,49 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'row_index' => {
      	datatype => 'int',
      	base_name => 'rowIndex',
-     	description => '',
+     	description => 'The row index.',
      	format => '',
      	read_only => '',
      		},
      'first_column' => {
      	datatype => 'int',
      	base_name => 'firstColumn',
-     	description => '',
+     	description => 'The first column index.',
      	format => '',
      	read_only => '',
      		},
      'last_column' => {
      	datatype => 'int',
      	base_name => 'lastColumn',
-     	description => '',
+     	description => 'The last column index.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
