@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,7 +59,7 @@ sub new {
 
 
 # Run Operation Request
-# PostBatchSplitRequest.batchSplitRequest :    
+# PostBatchSplitRequest.batchSplitRequest : BatchSplitRequest Batch splitting file request.     
 
 {
     my $params = {
@@ -70,7 +70,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_batch_split' } = { 
-    	summary => '',
+    	summary => 'Batch splitting files that meet specific matching conditions.',
         params => $params,
         returns => 'string',
     };
@@ -117,7 +117,7 @@ __PACKAGE__->method_documentation({
      'batch_split_request' => {
      	datatype => 'BatchSplitRequest',
      	base_name => 'batchSplitRequest',
-     	description => '',
+     	description => 'BatchSplitRequest Batch splitting file request.  ',
      	format => '',
      	read_only => '',
      		},    
