@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostCellCharactersRequest.name :   ,
-# PostCellCharactersRequest.sheetName :   ,
-# PostCellCharactersRequest.cellName :   ,
+# PostCellCharactersRequest.name : The file name.  ,
+# PostCellCharactersRequest.sheetName : The worksheet name.  ,
+# PostCellCharactersRequest.cellName : The cell name.  ,
 # PostCellCharactersRequest.options :   ,
-# PostCellCharactersRequest.folder :   ,
-# PostCellCharactersRequest.storageName :    
+# PostCellCharactersRequest.folder : The folder where the file is situated.  ,
+# PostCellCharactersRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_cell_characters' } = { 
-    	summary => '',
+    	summary => 'Set cell characters in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -144,21 +144,21 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'cell_name' => {
      	datatype => 'string',
      	base_name => 'cellName',
-     	description => '',
+     	description => 'The cell name.',
      	format => '',
      	read_only => '',
      		},
@@ -172,14 +172,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
