@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,10 +59,10 @@ sub new {
 
 
 # Run Operation Request
-# PostWorkbooksMergeRequest.name : Workbook name.  ,
+# PostWorkbooksMergeRequest.name : The file name.  ,
 # PostWorkbooksMergeRequest.mergeWith : The workbook to merge with.  ,
-# PostWorkbooksMergeRequest.folder : Original workbook folder.  ,
-# PostWorkbooksMergeRequest.storageName : Storage name.  ,
+# PostWorkbooksMergeRequest.folder : The folder where the file is situated.  ,
+# PostWorkbooksMergeRequest.storageName : The storage name where the file is situated.  ,
 # PostWorkbooksMergeRequest.mergedStorageName : Storage name.   
 
 {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_workbooks_merge' } = { 
-    	summary => 'Merge workbooks.',
+    	summary => 'Merge a workbook into the existing workbook.',
         params => $params,
         returns => 'WorkbookResponse',
     };
@@ -133,7 +133,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'Workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -147,14 +147,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},
