@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetCellsRangeRowHeightRequest.name :   ,
-# PostWorksheetCellsRangeRowHeightRequest.sheetName :   ,
-# PostWorksheetCellsRangeRowHeightRequest.range :   ,
-# PostWorksheetCellsRangeRowHeightRequest.value :   ,
-# PostWorksheetCellsRangeRowHeightRequest.folder :   ,
-# PostWorksheetCellsRangeRowHeightRequest.storageName :    
+# PostWorksheetCellsRangeRowHeightRequest.name : The file name.  ,
+# PostWorksheetCellsRangeRowHeightRequest.sheetName : The worksheet name.  ,
+# PostWorksheetCellsRangeRowHeightRequest.range : The range object.  ,
+# PostWorksheetCellsRangeRowHeightRequest.value : Sets the column height of this range.  ,
+# PostWorksheetCellsRangeRowHeightRequest.folder : Original workbook folder.  ,
+# PostWorksheetCellsRangeRowHeightRequest.storageName : Storage name.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_cells_range_row_height' } = { 
-    	summary => '',
+    	summary => 'Sets row height of range.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -142,42 +142,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'range' => {
      	datatype => 'Range',
      	base_name => 'range',
-     	description => '',
+     	description => 'The range object.',
      	format => '',
      	read_only => '',
      		},
      'value' => {
      	datatype => 'double',
      	base_name => 'value',
-     	description => '',
+     	description => 'Sets the column height of this range.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'Original workbook folder.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'Storage name.',
      	format => '',
      	read_only => '',
      		},    
