@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetListObjectSortTableRequest.name : The workbook name.  ,
+# PostWorksheetListObjectSortTableRequest.name : The file name.  ,
 # PostWorksheetListObjectSortTableRequest.sheetName : The worksheet name.  ,
-# PostWorksheetListObjectSortTableRequest.listObjectIndex : List object index.  ,
+# PostWorksheetListObjectSortTableRequest.listObjectIndex : The list object index.  ,
 # PostWorksheetListObjectSortTableRequest.dataSorter : Represents sort order for the data range.  ,
-# PostWorksheetListObjectSortTableRequest.folder : Original workbook folder.  ,
-# PostWorksheetListObjectSortTableRequest.storageName : Storage name.   
+# PostWorksheetListObjectSortTableRequest.folder : The folder where the file is situated.  ,
+# PostWorksheetListObjectSortTableRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_list_object_sort_table' } = { 
-    	summary => 'Sorts list object in worksheet.',
+    	summary => 'Sort list object in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -144,7 +144,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -158,7 +158,7 @@ __PACKAGE__->method_documentation({
      'list_object_index' => {
      	datatype => 'int',
      	base_name => 'listObjectIndex',
-     	description => 'List object index.',
+     	description => 'The list object index.',
      	format => '',
      	read_only => '',
      		},
@@ -172,14 +172,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
