@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetRangeSortRequest.name : The workbook name.  ,
+# PostWorksheetRangeSortRequest.name : The file name.  ,
 # PostWorksheetRangeSortRequest.sheetName : The worksheet name.  ,
 # PostWorksheetRangeSortRequest.cellArea : The area needed to sort.  ,
 # PostWorksheetRangeSortRequest.dataSorter : DataSorter with sorting settings.  ,
-# PostWorksheetRangeSortRequest.folder : The workbook folder.  ,
-# PostWorksheetRangeSortRequest.storageName : Storage name.   
+# PostWorksheetRangeSortRequest.folder : The folder where the file is situated.  ,
+# PostWorksheetRangeSortRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_range_sort' } = { 
-    	summary => 'Sorts range in worksheet.',
+    	summary => 'Sort a range in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -142,7 +142,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -170,14 +170,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'The workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
