@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetValidationRequest.name :   ,
-# PostWorksheetValidationRequest.sheetName :   ,
-# PostWorksheetValidationRequest.validationIndex :   ,
-# PostWorksheetValidationRequest.validation :   ,
-# PostWorksheetValidationRequest.folder :   ,
-# PostWorksheetValidationRequest.storageName :    
+# PostWorksheetValidationRequest.name : The workbook name.  ,
+# PostWorksheetValidationRequest.sheetName : The worksheet name.  ,
+# PostWorksheetValidationRequest.validationIndex : The validation index.  ,
+# PostWorksheetValidationRequest.validation : Validation description.  ,
+# PostWorksheetValidationRequest.folder : The folder where the file is situated.  ,
+# PostWorksheetValidationRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_validation' } = { 
-    	summary => '',
+    	summary => 'Update a validation by index in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -144,42 +144,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The workbook name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'validation_index' => {
      	datatype => 'int',
      	base_name => 'validationIndex',
-     	description => '',
+     	description => 'The validation index.',
      	format => '',
      	read_only => '',
      		},
      'validation' => {
      	datatype => 'Validation',
      	base_name => 'validation',
-     	description => '',
+     	description => 'Validation description.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
